#pragma once

#include <GL/glew.h>
#include <vector>

#include "glm/glm.hpp"

typedef std::vector<float> Vector6;

class Orbit
{
public:
    Orbit(Vector6 keplerianElements);
    void render();

    // TODO: meanAnomaly in all these arguments actually means eccentricMeanAnomaly,
    // will have to change that when adding non-ellipctical orbits - don't get confused!
    glm::vec3 getPosition(const float meanAnomaly);
    glm::vec3 getTangent(const float meanAnomaly);

    void setElements(Vector6 keplerianElements);

    ~Orbit(); 
private:
    const float _pi = 3.14159265359;
    const int _vertexCount = 100;

    GLuint _vbo;
    GLuint _vao;

    std::vector<float> _vertices;
    Vector6 _keplerianElements;

    void regenerateVertices();

    float getEccentricAnomaly(const float meanAnomaly);
    float getTrueAnomaly(const float meanAnomaly);
    Vector6 getCartesianCoordinates(const float meanAnomaly);
};
